from setuptools import setup, find_packages
import codecs
import os

VERSION = "0.0.1"
DESCRIPTION = "Mike\'s Hello World Package"

setup(
    name="MikePackageTest",
    version=VERSION,
    author="Mike K",
    author_email="mkitlan@gmail.com",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'mike'],
    classifiers=[
            "Development Status :: 1 - Planning"
    ]
)
